version 12.0
clear
set more off

use "revoltonnile_appendix_nileyear.dta", clear


label var nileyear "Year"


log using "revoltonnile_appendix_nileyear.txt", text replace

****************************
*** Figure 1 of Appendix ***
****************************
preserve
gen graphshock=shock
replace graphshock=. if shock==0
gen graphch=ch/100
replace graphch=graphch*0.99
replace graphch=. if graphch==0
drop if after1169==0
twoway (tsline nilemax, ytitle("Meters above Sea Level") legend(off)  lstyle(solid) lcolor(gs10) scheme(sj) scale(0.6)   graphregion(fcolor(white))) (tsline trend, lstyle(solid) lcolor(black)) (tsline upper, lstyle(solid) lcolor(gs10)) (tsline lower, lstyle(solid) lcolor(gs10))  (scatter graphshock nileyear, yaxis(2) msymbol(o) mcolor(gs1)) (scatter graphch nileyear, yaxis(2) yscale(range(0 1) axis(2) off) msymbol(o) mcolor(gs11))
graph export "nilemaxappendix.eps", as(eps) preview(off) replace
restore


*HP filter
tsset nileyear, yearly
tsfilter hp hpres=nilemax, t(hp)

*MA 25
tssmooth ma fit=nilemax, window(25 0 0)
gen mares=nilemax-fit

*lag length selected using AIC, max lag length 30
reg nilemax l(1/15).nilemax if nileyear>670
predict ar, r


*Generating alternative residuals, 10% cutoff
local vars "hpres mares ar"
foreach x of local vars {
egen nile95`x'=pctile(`x'), p(95) 
egen nile5`x'=pctile(`x'), p(5)
gen drought`x'=(`x'<=nile5`x') 
replace drought`x'=. if `x'==.
gen flood`x'=(`x'>=nile95`x') 
replace flood`x'=. if `x'==.
gen shock`x'=drought`x'+flood`x'
}

*Linear residuals, 15% cutoff
egen nile925=pctile(li), p(92.5) 
egen nile75=pctile(li), p(7.5)
gen drought15=(li<=nile75) 
replace drought15=. if li==.
gen flood15=(li>=nile925) 
replace flood15=. if li==.
gen shock15=drought15+flood15

*Linear residuals, 25% cutoff
egen nile875=pctile(li), p(87.5) 
egen nile125=pctile(li), p(12.5)
gen drought25=(li<=nile125) 
replace drought25=. if li==.
gen flood25=(li>=nile875) 
replace flood25=. if li==.
gen shock25=drought25+flood25

*Decade dummies
tab dec, gen(d)


***************************
*** Table 2 of Appendix ***
***************************

preserve
drop if nileyear>1425
*Col. 1
newey ch shock d1-d80 if after1169==1, lag(10)

*Col. 2
newey ch shockhpres d1-d80 if after1169==1, lag(10)

*Col. 3
newey ch shockmares d1-d80 if after1169==1, lag(10)

*Col. 4
newey ch shockar d1-d80 if after1169==1, lag(10)

*Col. 5
newey ch shock5 d1-d80 if after1169==1, lag(10)

*Col. 6
newey ch shock15 d1-d80 if after1169==1, lag(10)

*Col. 7
newey ch shock25 d1-d80 if after1169==1, lag(10)
restore

*Col. 8
newey ch shock d1-d80 if after1169==1, lag(10)

*Col. 9
newey ch shockhpres d1-d80 if after1169==1, lag(10)

*Col. 10
newey ch shockmares d1-d80 if after1169==1, lag(10)

*Col. 11
newey ch shockar d1-d80 if after1169==1, lag(10)

*Col. 12
newey ch shock5 d1-d80 if after1169==1, lag(10)

*Col. 13
newey ch shock15 d1-d80 if after1169==1, lag(10)

*Col. 14
newey ch shock25 d1-d80 if after1169==1, lag(10)


***************************
*** Table 3 of Appendix ***
***************************
*Col. 1
newey ch shock if after1169==1, lag(10)
qui reg ch shock if after1169==1
estat bgod, lags(10)

*Col. 2
newey ch shock mamluk if after1169==1, lag(10)
qui reg ch shock mamluk if after1169==1
estat bgod, lags(10)

*Col. 3
newey ch shock d1-d80 if after1169==1, lag(10)
qui reg ch shock d1-d80 if after1169==1
estat bgod, lags(10)

*Col. 4
reg ch shock l(1/2).ch l(1/5).shock f(1/5).shock mamluk if after1169==1, r
testparm L(1/5).shock 
testparm F(1/5).shock

qui reg ch shock l(1/2).ch l(1/5).shock f(1/5).shock mamluk if after1169==1
estat bgod, lags(10)

*Col. 5
reg ch shock l(1/2).ch l(1/10).shock f(1/10).shock mamluk if after1169==1, r
testparm L(1/10).shock 
testparm F(1/10).shock

qui reg ch shock l(1/2).ch l(1/10).shock f(1/10).shock mamluk if after1169==1
estat bgod, lags(10)


*Col. 6
newey dif shock if after1169==1, lag(10)
qui reg dif shock if after1169==1
estat bgod, lags(10)
*Col. 7
newey dif shock mamluk if after1169==1, lag(10)
qui reg dif shock mamluk if after1169==1
estat bgod, lags(10)

*Col. 8
newey dif shock d1-d80 if after1169==1, lag(10)
qui reg dif shock d1-d80 if after1169==1
estat bgod, lags(10)


*Col. 9
reg dif shock l(1/2).dif l(1/5).shock f(1/5).shock mamluk if after1169==1, r
testparm L(1/5).shock 
testparm F(1/5).shock

qui reg dif shock l(1/2).dif l(1/5).shock f(1/5).shock mamluk if after1169==1
estat bgod, lags(10)

*Col. 10
reg dif shock l(1/2).dif l(1/10).shock f(1/10).shock mamluk if after1169==1, r
testparm L(1/10).shock 
testparm F(1/10).shock

qui reg dif shock l(1/2).dif l(1/10).shock f(1/10).shock mamluk if after1169==1
estat bgod, lags(10)



***************************
*** Table 4 of Appendix ***
***************************

*Col. 1
newey stsala shock d1-d80, lag(10)

*Col. 2

gen early=(after1169==1)
gen baseline=(after1169==0)


gen ibase=baseline*shock
gen iearly=early*shock

newey ch ibase iearly d1-d80, lag(10)
test ibase=iearly


*Col. 3
preserve
keep if nileyear>1265

qui reg ch shock d1-d79
estimates store shafi
qui reg chm shock d1-d79
estimates store maliki
qui reg chhnf shock d1-d79
estimates store hanafi
qui reg chhnb shock d1-d79
estimates store hanbali


suest shafi maliki hanafi hanbali, robust
test [shafi_mean]shock=[hanbali_mean]shock=[hanafi_mean]shock=[maliki_mean]shock
restore

*Col. 4
newey stcrus shock d1-d80, lag(10)

*Col. 5
preserve
replace stcrus=stcrus/100
newey ch stcrus d1-d80, lag(10)
restore

*Col. 6
newey stghala shock d1-d80, lag(10)

*Col. 7
newey stunrest shock d1-d80, lag(10)

*Col. 8 and 9
preserve
drop if province==1
sort nileyear
gen time=_n
tsset time
newey chl shock d1-d80, lag(10)
newey chl shock5 d1-d80, lag(10) 
restore

preserve
*Col. 10
replace stghala=stghala/100
ivreg2 ch (stghala=shock) d1-d80, small robust bw(11) partial(d1-d80) first
ivreg2 ch (stghala=shock) d1-d80, cluster(dec) partial(d1-d80)
rivtest, ci
restore


***************************
*** Table 5 of Appendix ***
***************************
*Col. 1
newey streligious shock if after1169==1, lag(10)

*Col. 2
newey stgovt shock if after1169==1, lag(10)

*Col. 3
newey dif shock if after1169==1, lag(10)

*Col. 4
newey strnd shock if after1169==1, lag(10)

*Col. 5
newey stgovt shock if after1169==1, lag(10)

*Col. 6
newey difnd shock if after1169==1, lag(10)

*Col. 7
newey streligious shock if after1169==1, lag(10)

*Col. 8
newey stgnc shock if after1169==1, lag(10)

*Col. 9
newey difnc shock if after1169==1, lag(10)


***************************
*** Table 6 of Appendix ***
***************************

*Col. 1
newey chl shock, lag(10)


*Col. 2
newey chl shock5, lag(10)

*Col. 3
newey chl shock if nileyear<=1425, lag(10)

*Col. 4
newey chl shock5  if nileyear<=1425, lag(10)

*Cols. 5-8
preserve
drop if province==1
drop if nileyear>1425
sort nileyear
gen time=_n
tsset time
*Col. 5
newey chl shock, lag(10)

*Col. 6
newey chl shock5, lag(10) 

*Col. 7
newey chl shock d1-d80, lag(10)

*Col. 8
newey chl shock5 d1-d80, lag(10) 

restore

*Col. 9
newey chl shock d1-d80 if after1169==1 & nileyear<=1425, lag(10)

*Col. 10
newey chl shock5 d1-d80 if after1169==1 & nileyear<=1425, lag(10)

***************************
*** Table 7 of Appendix ***
***************************

**Panel A**
*Col. 1
newey stsala drought flood if after1169==1 & nileyear<=1425, lag(10)
test drought=flood

*Col. 2
newey stsala drought flood d1-d80 if after1169==1 & nileyear<=1425, lag(10)
test drought=flood

*Col. 3
newey stghala drought flood if after1169==1 & nileyear<=1425, lag(10)
test drought=flood

*Col. 4
newey stghala drought flood d1-d80 if after1169==1 & nileyear<=1425, lag(10)
test drought=flood

*Col. 5
newey stunrest drought flood if after1169==1 & nileyear<=1425, lag(10)
test drought=flood

*Col. 6
newey stunrest drought flood d1-d80 if after1169==1 & nileyear<=1425, lag(10)
test drought=flood

**Panel B**
*Col. 1
newey stsala drought flood if after1169==1, lag(10)
test drought=flood

*Col. 2
newey stsala drought flood d1-d80 if after1169==1, lag(10)
test drought=flood

*Col. 3
newey stghala drought flood if after1169==1, lag(10)
test drought=flood

*Col. 4
newey stghala drought flood d1-d80 if after1169==1, lag(10)
test drought=flood

*Col. 5
newey stunrest drought flood if after1169==1, lag(10)
test drought=flood

*Col. 6
newey stunrest drought flood d1-d80 if after1169==1, lag(10)
test drought=flood


***************************
*** Table 9 of Appendix ***
***************************


sum shock if province==1
sum shock if tulunid==1
sum shock if fatimi==1
sum shock if ayyubid==1
sum shock if mamluk==1
sum shock if after1169==1
sum shock if after1169==0
sum shock if after1169==1 & nileyear<=1425


sum ch if province==1
sum ch if tulunid==1
sum ch if fatimi==1
sum ch if ayyubid==1
sum ch if mamluk==1
sum ch if after1169==1
sum ch if after1169==0
sum ch if after1169==1 & nileyear<=1425

sum chl if province==1
sum chl if tulunid==1
sum chl if fatimi==1
sum chl if ayyubid==1
sum chl if mamluk==1
sum chl if after1169==1
sum chl if after1169==0
sum chl if after1169==1 & nileyear<=1425


sum dif if province==1
sum dif if tulunid==1
sum dif if fatimi==1
sum dif if ayyubid==1
sum dif if mamluk==1
sum dif if after1169==1
sum dif if after1169==0
sum dif if after1169==1 & nileyear<=1425

sum stsala if ayyubid==1
sum stsala if mamluk==1
sum stsala if after1169==1
sum stsala if after1169==1 & nileyear<=1425


sum stghala if ayyubid==1
sum stghala if mamluk==1
sum stghala if after1169==1
sum stghala if after1169==1 & nileyear<=1425

sum stunrest if ayyubid==1
sum stunrest if mamluk==1
sum stunrest if after1169==1
sum stunrest if after1169==1 & nileyear<=1425

sum stcrus if ayyubid==1
sum stcrus if mamluk==1
sum stcrus if after1169==1
sum stcrus if after1169==1 & nileyear<=1425

log close
