version 12.0

clear
set more off
use "revoltonnile_main.dta", clear


log using "revoltonnile_main.txt", text replace


/*Baseline sample consists of all years after 1169 after omitting flurry of Nile shocks after 1425*/
gen baseline=after1169
replace baseline=0 if nileyear>1425

****************
*** Figure 1 ***
****************
preserve
gen graphshock=shock
replace graphshock=. if shock==0
gen graphch=ch/100
replace graphch=graphch*0.99
replace graphch=. if graphch==0
drop if baseline==0
twoway (tsline nilemax, ytitle("Meters above Sea Level") legend(off)  lstyle(solid) lcolor(gs10) scheme(sj) scale(0.6)   graphregion(fcolor(white))) (tsline trend, lstyle(solid) lcolor(black)) (tsline upper, lstyle(solid) lcolor(gs10)) (tsline lower, lstyle(solid) lcolor(gs10))  (scatter graphshock nileyear, yaxis(2) msymbol(o) mcolor(gs1)) (scatter graphch nileyear, yaxis(2) yscale(range(0 1) axis(2) off) msymbol(o) mcolor(gs11))
graph export "nilemax.eps", as(eps) preview(off) replace
restore

***************
*** Table 1 ***
***************
sum ch if baseline==1
sum ch if baseline==1 & shock==1
sum ch if baseline==1 & shock==0


sum ch if nileyear<1169
sum ch if nileyear<1169 & shock==1
sum ch if nileyear<1169 & shock==0

*Generating decade dummies
tab dec, gen(d)

***************
*** Table 2 ***
***************
*Col. 1
newey ch shock if baseline==1, lag(10)
qui reg ch shock if baseline==1
estat bgod, lags(10)

*Col. 2
newey ch shock mamluk if baseline==1, lag(10)
qui reg ch shock mamluk if baseline==1
estat bgod, lags(10)

*Col. 3
newey ch shock d1-d80 if baseline==1, lag(10)
qui reg ch shock d1-d80 if baseline==1
estat bgod, lags(10)

*Col. 4
reg ch shock l(1/2).ch l(1/5).shock f(1/5).shock mamluk if baseline==1, r
testparm L(1/5).shock 
testparm F(1/5).shock

qui reg ch shock l(1/2).ch l(1/5).shock f(1/5).shock mamluk if baseline==1
estat bgod, lags(10)

*Col. 5
reg ch shock l(1/2).ch l(1/10).shock f(1/10).shock mamluk if baseline==1, r
testparm F(1/10).shock
testparm L(1/10).shock

*The lag result is robustly driven by 8th lag, for example when decade dummies are added:
areg ch shock l(1/2).ch l(1/10).shock f(1/10).shock mamluk if baseline==1, absorb(dec) r
testparm L(1/7).shock L(9/10).shock
testparm L(1/10).shock
testparm F(1/10).shock

qui reg ch shock l(1/2).ch l(1/10).shock f(1/10).shock mamluk if baseline==1
estat bgod, lags(10)

*Col. 6
newey dif shock if baseline==1, lag(10)
qui reg dif shock if baseline==1
estat bgod, lags(10)

*Col. 7
newey dif shock mamluk if baseline==1, lag(10)
qui reg dif shock mamluk if baseline==1
estat bgod, lags(10)

*Col. 8
newey dif shock d1-d80 if baseline==1, lag(10)
qui reg dif shock d1-d80 if baseline==1
estat bgod, lags(10)

*Col. 9
reg dif shock l(1/2).dif l(1/5).shock f(1/5).shock mamluk if baseline==1, r
testparm L(1/5).shock 
testparm F(1/5).shock

qui reg dif shock l(1/2).dif l(1/5).shock f(1/5).shock mamluk if baseline==1
estat bgod, lags(10)

*Col. 10
reg dif shock l(1/2).dif l(1/10).shock f(1/10).shock mamluk if baseline==1, r
testparm L(1/10).shock 
testparm F(1/10).shock

qui reg dif shock l(1/2).dif l(1/10).shock f(1/10).shock mamluk if baseline==1
estat bgod, lags(10)



***************
*** Table 3 ***
***************
drop if nileyear>1425

*Col. 1
newey stsala shock d1-d80, lag(10)

*Col. 2

gen early=(baseline==0)

gen ibase=baseline*shock
gen iearly=early*shock

newey ch ibase iearly d1-d80, lag(10)
test ibase=iearly

*Col. 3
preserve
keep if nileyear>1265

qui reg ch shock d1-d78
estimates store shafi
qui reg chm shock d1-d78
estimates store maliki
qui reg chhnf shock d1-d78
estimates store hanafi
qui reg chhnb shock d1-d78
estimates store hanbali


suest shafi maliki hanafi hanbali, robust
test [shafi_mean]shock=[hanbali_mean]shock=[hanafi_mean]shock=[maliki_mean]shock
restore

*Col. 4
newey stcrus shock d1-d80, lag(10)


*Col. 5
replace stcrus=stcrus/100
newey ch stcrus d1-d80, lag(10)

*Col. 6
newey stghala shock d1-d80, lag(10)

*Col. 7
newey stunrest shock d1-d80, lag(10)

*Col. 8 and 9
preserve
drop if province==1
sort nileyear
gen time=_n
tsset time
newey chl shock d1-d80, lag(10)
newey chl shock5 d1-d80, lag(10) 
restore

*Col. 10
replace stghala=stghala/100
ivreg2 ch (stghala=shock) d1-d80, small robust bw(11) partial(d1-d80) first
ivreg2 ch (stghala=shock) d1-d80, cluster(dec) partial(d1-d80)
rivtest, ci


log close

